==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebGroupByRowTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByRecordDescriptionMetadata } from "./WebGroupByRecordDescriptionMetadata";
import { WebGroupByRowTemplateContextDescription } from "./WebGroupByRowTemplateContextDescription";
/**
 * @hidden
 */
var WebGroupByRowTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGroupByRowTemplateContextDescriptionMetadata, _super);
    function WebGroupByRowTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupByRowTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGroupByRowTemplateContextDescriptionMetadata.a == null) {
            WebGroupByRowTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupByRowTemplateContextDescriptionMetadata.c(WebGroupByRowTemplateContextDescriptionMetadata.a);
        }
        if (a.j(WebGroupByRowTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGroupByRowTemplateContextDescriptionMetadata.a);
        WebGroupByRecordDescriptionMetadata.d(a);
    };
    WebGroupByRowTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupByRowTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Implicit", "ExportedType:WebGroupByRecord");
    };
    WebGroupByRowTemplateContextDescriptionMetadata.d = function (a) {
        WebGroupByRowTemplateContextDescriptionMetadata.b(a);
        a.aa("WebGroupByRowTemplateContext", function () { return new WebGroupByRowTemplateContextDescription(); });
        a.z("WebGroupByRowTemplateContext", WebGroupByRowTemplateContextDescriptionMetadata.a);
    };
    WebGroupByRowTemplateContextDescriptionMetadata.$t = markType(WebGroupByRowTemplateContextDescriptionMetadata, 'WebGroupByRowTemplateContextDescriptionMetadata');
    WebGroupByRowTemplateContextDescriptionMetadata.a = null;
    return WebGroupByRowTemplateContextDescriptionMetadata;
}(Base));
export { WebGroupByRowTemplateContextDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebGroupByRowTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByRecordDescriptionMetadata } from "./WebGroupByRecordDescriptionMetadata";
import { WebGroupByRowTemplateContextDescription } from "./WebGroupByRowTemplateContextDescription";
/**
 * @hidden
 */
var WebGroupByRowTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGroupByRowTemplateContextDescriptionMetadata, _super);
    function WebGroupByRowTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupByRowTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGroupByRowTemplateContextDescriptionMetadata.a == null) {
            WebGroupByRowTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupByRowTemplateContextDescriptionMetadata.c(WebGroupByRowTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebGroupByRowTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGroupByRowTemplateContextDescriptionMetadata.a);
        WebGroupByRecordDescriptionMetadata.d(a);
    };
    WebGroupByRowTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupByRowTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "ExportedType:WebGroupByRecord");
    };
    WebGroupByRowTemplateContextDescriptionMetadata.d = function (a) {
        WebGroupByRowTemplateContextDescriptionMetadata.b(a);
        a.ac("WebGroupByRowTemplateContext", function () { return new WebGroupByRowTemplateContextDescription(); });
        a.ab("WebGroupByRowTemplateContext", WebGroupByRowTemplateContextDescriptionMetadata.a);
    };
    WebGroupByRowTemplateContextDescriptionMetadata.$t = markType(WebGroupByRowTemplateContextDescriptionMetadata, 'WebGroupByRowTemplateContextDescriptionMetadata');
    WebGroupByRowTemplateContextDescriptionMetadata.a = null;
    return WebGroupByRowTemplateContextDescriptionMetadata;
}(Base));
export { WebGroupByRowTemplateContextDescriptionMetadata };
